==> gambit-0.2005.12.12.tar.gz: gambit-0.2005.12.12/sources/tools/enumpoly/behavextend.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/Attic/behavextend.h,v $
// $Date: 2005/06/30 17:24:33 $
// $Revision: 1.1.2.3 $
//
// DESCRIPTION:
// Algorithms for extending behavior profiles to Nash equilibria
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef BEHAVEXTEND_H
#define BEHAVEXTEND_H

#include "libgambit/libgambit.h"

class algExtendsToNash {
public:
  bool ExtendsToNash(const gbtBehavProfile<double> &p_solution,
		     const gbtEfgSupport &p_littleSupport,
		     const gbtEfgSupport &p_bigSupport);
};

class algExtendsToAgentNash {
public:
  bool ExtendsToAgentNash(const gbtBehavProfile<double> &p_solution,
			  const gbtEfgSupport &p_littleSupport,
			  const gbtEfgSupport &p_bigSupport);
};



#endif   // BEHAVEXTEND_H

==> gambit-0.2007.01.30.tar.gz: gambit-0.2007.01.30/sources/tools/enumpoly/behavextend.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/behavextend.h,v $
// $Date: 2006/01/05 18:48:48 $
// $Revision: 1.4 $
//
// DESCRIPTION:
// Algorithms for extending behavior profiles to Nash equilibria
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef BEHAVEXTEND_H
#define BEHAVEXTEND_H

#include "libgambit/libgambit.h"

class algExtendsToNash {
public:
  bool ExtendsToNash(const Gambit::MixedBehavProfile<double> &p_solution,
		     const Gambit::BehavSupport &p_littleSupport,
		     const Gambit::BehavSupport &p_bigSupport);
};

class algExtendsToAgentNash {
public:
  bool ExtendsToAgentNash(const Gambit::MixedBehavProfile<double> &p_solution,
			  const Gambit::BehavSupport &p_littleSupport,
			  const Gambit::BehavSupport &p_bigSupport);
};



#endif   // BEHAVEXTEND_H
